package member_service

import (
	"SCRM/models"
	"SCRM/service"
	"errors"
	"strings"
	"time"
)

func GetTagList(orgID int64) (tags []*models.UserTags, err error) {
	err = service.UserReadDB().Model(&models.UserTags{}).Where("user_org_id=? and status=1", orgID).Order("id asc").Find(&tags).Error

	return
}

//GetMemberAllTags 取所有(包括已经软删除的记录)
func GetMemberAllTags(orgID, customerID int64) (tags []*models.UserTagLinks, err error) {
	err = service.UserReadDB().Where("user_org_id = ? and user_link_id =? ", orgID, customerID).Find(&tags).Error
	return
}

//GetMembersAllTags 取所有(包括已经软删除的记录)
func GetMembersAllTags(orgID int64, customerIDs []int64) (tags []*models.UserTagLinks, err error) {
	err = service.UserReadDB().Where("user_org_id = ? and user_link_id in (?) ", orgID, customerIDs).Find(&tags).Error
	return
}

//DeleteMemeberAllTags 删除会员所有标签
func DeleteMemeberAllTags(orgID, customerID int64) (err error) {
	err = service.UserWriteDB().Model(&models.UserTagLinks{}).Where("user_org_id = ? and user_link_id =? ", orgID, customerID).Update(map[string]interface{}{"Status": 0, "UpdatedTime": time.Now().Unix()}).Error
	return
}

func SaveMemberTags(tags []*models.UserTagLinks) (err error) {
	if len(tags) == 0 {
		err = errors.New("NotRecordToUpdate")
		return
	}

	insertSql := "INSERT INTO sgj_user_tag_links (tag_id, user_link_id, status, created_time, updated_time, user_org_id) VALUES "
	insertParams := make([]string, 0)
	insertData := make([]interface{}, 0)
	updateIds := make([]int64, 0)
	deleteIds := make([]int64, 0)
	for _, tag := range tags {
		if tag.ID == 0 {
			insertParams = append(insertParams, "(?,?,?,?,?,?)")
			insertData = append(insertData, tag.TagId)
			insertData = append(insertData, tag.UserLinkId)
			insertData = append(insertData, tag.Status)
			insertData = append(insertData, tag.CreatedTime)
			insertData = append(insertData, tag.UpdatedTime)
			insertData = append(insertData, tag.UserOrgId)
		} else {
			if tag.Status == 1 {
				updateIds = append(updateIds, tag.ID)
			} else {
				deleteIds = append(deleteIds, tag.ID)
			}
		}
	}

	tx := service.UserWriteDB().Begin()
	if len(insertParams) > 0 {
		insertSql += strings.Join(insertParams, ", ")
		err = tx.Exec(insertSql, insertData...).Error
		if err != nil {
			tx.Rollback()
			return
		}
	}

	if len(updateIds) > 0 {
		err = service.UserWriteDB().Model(&models.UserTagLinks{}).Where("id IN (?)", updateIds).Update(map[string]interface{}{"Status": 1, "UpdatedTime": time.Now().Unix()}).Error
		if err != nil {
			tx.Rollback()
			return
		}
	}
	if len(deleteIds) > 0 {
		err = service.UserWriteDB().Model(&models.UserTagLinks{}).Where("id IN (?)", deleteIds).Update(map[string]interface{}{"Status": 0, "UpdatedTime": time.Now().Unix()}).Error
		if err != nil {
			tx.Rollback()
			return
		}
	}

	tx.Commit()
	return
}

func GetPageTagList(orgID, page, limit int64, search string) (tags []*Tags, err error) {
	db := service.UserReadDB().Model(&models.UserTags{}).Where("user_org_id=? and status=1", orgID)

	if len(search) > 0 {
		searchKey := "%" + search + "%"
		db = db.Where("tag_name LIKE ?", searchKey)
	}
	offset := (page - 1) * limit

	err = service.UserReadDB().Model(&models.UserTags{}).Where("user_org_id=? and status=1", orgID).Order("id desc").Offset(offset).Limit(limit).Find(&tags).Error

	if len(tags) > 0 {
		// var tmcs []*TagsMemberCount
		// tagIDs := make([]int64, 0)
		// for _, tag := range tags {
		// 	tagIDs = append(tagIDs, tag.ID)
		// }

	}
	return
}
